@@ -317,7 +317,8 @@ class PalObj():
         if equal_legs == True:
             boundaries = np.linspace(self.cols[0].val_low,self.cols[-1].val_high,n_cols+1)
 
-        ax.imshow(pal_rgb, axes=ax, aspect='auto',extent=[0.,1,boundaries[0],boundaries[-1]],interpolation='nearest')
+        ax.imshow(pal_rgb, axes=ax, aspect='auto',extent=[0.,1,boundaries[0],boundaries[-1]],
+                  interpolation='nearest', origin='upper')
         ax.set_xticks([])
         ax.set_yticks(boundaries)
         ax.set_yticklabels(labels)
@@ -413,9 +414,9 @@ class PalObj():
             x1, x2 = ax.get_xlim()
             y1, y2 = ax.get_ylim()
 
-        #call imshow to plot the data
-        ax.imshow(out_rgb, axes=ax, interpolation='nearest',
-                  extent=[x1,x2,y1,y2], zorder=zorder)
+        #call imshow to plot the data   TODO adjust for cartopy 0.18
+        ax.imshow(out_rgb, axes=ax, interpolation='nearest', 
+                  origin='upper', extent=[x1,x2,y1,y2], zorder=zorder)
         ax.set_aspect(aspect)
 
         #plot palette if desired
